@@ -1,8 +1,11 @@
 #!/usr/bin/env python
 #
-# SNMP Simulator MIB to data file converter
+# This file is part of snmpsim software.
 #
-# Written by Ilya Etingof <ilya@glas.net>, 2011-2015
+# Copyright (c) 2010-2019, Ilya Etingof <etingof@gmail.com>
+# License: http://snmplabs.com/snmpsim/license.html
+#
+# SNMP Simulator MIB to data file converter
 #
 import getopt
 import sys
@@ -20,11 +23,11 @@ from snmpsim.error import SnmpsimError
 verboseFlag = True
 startOID = stopOID = None
 mibSources = []
-defaultMibSources = [ 'http://mibs.snmplabs.com/asn1/@mib@' ]
+defaultMibSources = ['http://mibs.snmplabs.com/asn1/@mib@']
 outputFile = sys.stdout
 if hasattr(outputFile, 'buffer'):
     outputFile = outputFile.buffer
-stringPool = 'Portez ce vieux whisky au juge blond qui fume!'.split()
+stringPool = 'Jaded zombies acted quaintly but kept driving their oxen forward'.split()
 counterRange = (0, 0xffffffff)
 counter64Range = (0, 0xffffffffffffffff)
 gaugeRange = (0, 0xffffffff)
@@ -41,6 +44,7 @@ helpMessage = """Usage: %s [--help]
     [--debug=<%s>]
     [--quiet]
     [--mib-source=<url>]
+    [--pysnmp-mib-dir=</path/to/pysnmp/mibs]
     [--mib-module=<MIB-NAME>]
     [--start-object=<MIB-NAME::[symbol-name]|OID>]
     [--stop-object=<MIB-NAME::[symbol-name]|OID>]
@@ -49,33 +53,35 @@ helpMessage = """Usage: %s [--help]
     [--table-size=<number>]
     [--output-file=<filename>]
     [--string-pool=<words>]
+    [--string-pool-file=</path/to/text/file>]
     [--counter-range=<min,max>]
     [--counter64-range=<min,max>]
     [--gauge-range=<min,max>]
     [--timeticks-range=<min,max>]
     [--unsigned-range=<min,max>]
     [--integer32-range=<min,max>]""" % (
-        sys.argv[0], 
-        '|'.join([ x for x in debug.flagMap.keys() if x not in ('app', 'msgproc', 'proxy', 'io', 'secmod', 'dsp', 'acl') ])
-    )
+    sys.argv[0],
+    '|'.join([x for x in getattr(debug, 'FLAG_MAP', getattr(debug, 'flagMap', ()))
+              if x not in ('app', 'msgproc', 'proxy', 'io', 'secmod', 'dsp', 'acl')])
+)
 
 try:
     opts, params = getopt.getopt(sys.argv[1:], 'hv', [
-        'help', 'version', 'debug=', 'quiet', 
+        'help', 'version', 'debug=', 'quiet',
         'pysnmp-mib-dir=', 'mib-module=', 'start-oid=', 'stop-oid=',
         'mib-source=', 'start-object=', 'stop-object=',
-        'manual-values', 'automatic-values=', 'table-size=', 
-        'output-file=', 'string-pool=', 'integer32-range=',
+        'manual-values', 'automatic-values=', 'table-size=',
+        'output-file=', 'string-pool=', 'string-pool-file=', 'integer32-range=',
         'counter-range=', 'counter64-range=', 'gauge-range=',
         'unsigned-range=', 'timeticks-range='
-    ] )
+    ])
 except Exception:
     sys.stderr.write('ERROR: %s\r\n%s\r\n' % (sys.exc_info()[1], helpMessage))
     sys.exit(-1)
 
 if params:
     sys.stderr.write('ERROR: extra arguments supplied %s\r\n%s\r\n' % (params, helpMessage))
-    sys.exit(-1)    
+    sys.exit(-1)
 
 for opt in opts:
     if opt[0] == '-h' or opt[0] == '--help':
@@ -85,19 +91,27 @@ Synopsis:
   Chooses random values or can ask for them interactively.
   Able to fill SNMP conceptual tables with consistent indices.
 Documentation:
-  http://snmpsim.sourceforge.net/simulation-based-on-mibs.html
+  http://snmplabs.com/snmpsim/simulation-based-on-mibs.html
 %s
 """ % helpMessage)
         sys.exit(-1)
     if opt[0] == '-v' or opt[0] == '--version':
-        import snmpsim, pysmi, pysnmp, pyasn1
+        import snmpsim
+        import pysmi
+        import pysnmp
+        import pyasn1
+
         sys.stderr.write("""\
-SNMP Simulator version %s, written by Ilya Etingof <ilya@glas.net>
+SNMP Simulator version %s, written by Ilya Etingof <etingof@gmail.com>
 Using foundation libraries: pysmi %s, pysnmp %s, pyasn1 %s.
 Python interpreter: %s
-Software documentation and support at http://snmpsim.sf.net
+Software documentation and support at http://snmplabs.com/snmpsim
 %s
-""" % (snmpsim.__version__, hasattr(pysmi, '__version__') and pysmi.__version__ or 'unknown', hasattr(pysnmp, '__version__') and pysnmp.__version__ or 'unknown', hasattr(pyasn1, '__version__') and pyasn1.__version__ or 'unknown', sys.version, helpMessage))
+""" % (snmpsim.__version__,
+       hasattr(pysmi, '__version__') and pysmi.__version__ or 'unknown',
+       hasattr(pysnmp, '__version__') and pysnmp.__version__ or 'unknown',
+       hasattr(pyasn1, '__version__') and pyasn1.__version__ or 'unknown',
+       sys.version, helpMessage))
         sys.exit(-1)
     if opt[0] == '--debug':
         debug.setLogger(debug.Debug(*opt[1].split(',')))
@@ -116,9 +130,9 @@ Software documentation and support at http://snmpsim.sf.net
     if opt[0] == '--mib-source':
         mibSources.append(opt[1])
     if opt[0] == '--start-object':
-        startOID = ObjectIdentity(*opt[1].split('::'))
+        startOID = ObjectIdentity(*opt[1].split('::', 1))
     if opt[0] == '--stop-object':
-        stopOID = ObjectIdentity(*opt[1].split('::'), **dict(last=True))
+        stopOID = ObjectIdentity(*opt[1].split('::', 1), **dict(last=True))
     if opt[0] == '--manual-values':
         automaticValues = 0
     if opt[0] == '--automatic-values':
@@ -126,22 +140,31 @@ Software documentation and support at http://snmpsim.sf.net
             automaticValues = int(opt[1])
         except ValueError:
             sys.stderr.write('ERROR: bad value %s: %s\r\n' % (opt[1], sys.exc_info()[1]))
-            sys.exit(-1)   
+            sys.exit(-1)
     if opt[0] == '--table-size':
         try:
             tableSize = int(opt[1])
         except ValueError:
             sys.stderr.write('ERROR: bad value %s: %s\r\n' % (opt[1], sys.exc_info()[1]))
-            sys.exit(-1)   
+            sys.exit(-1)
     if opt[0] == '--output-file':
         outputFile = open(opt[1], 'wb')
     if opt[0] == '--string-pool':
         stringPool = opt[1].split()
+    if opt[0] == '--string-pool-file':
+        try:
+            f = open(opt[1])
+            stringPool = f.read().split()
+            f.close()
+        except Exception:
+            sys.stderr.write('ERROR: text file "%s" open failure %s\r\n' % (opt[1], sys.exc_info()[1]))
+            sys.exit(-1)
     if opt[0] == '--counter-range':
         try:
             counterRange = [int(x) for x in opt[1].split(',')]
         except ValueError:
-            sys.stderr.write('ERROR: bad value %s: %s\r\n' % (opt[1], sys.exc_info()[1]))
+            sys.stderr.write(
+                'ERROR: bad value %s: %s\r\n' % (opt[1], sys.exc_info()[1]))
             sys.exit(-1)
     if opt[0] == '--counter64-range':
         try:
@@ -174,23 +197,21 @@ Software documentation and support at http://snmpsim.sf.net
             sys.stderr.write('ERROR: bad value %s: %s\r\n' % (opt[1], sys.exc_info()[1]))
             sys.exit(-1)
 
-
 # Catch missing params
 if not modNames:
     sys.stderr.write('ERROR: MIB modules not specified\r\n%s\r\n' % helpMessage)
-    sys.exit(-1)    
+    sys.exit(-1)
+
 
 def getValue(syntax, hint='', automaticValues=automaticValues):
     # Optionally approve chosen value with the user
     makeGuess = automaticValues
     val = None
-    while 1:
+    while True:
         if makeGuess:
             # Pick a value
             if isinstance(syntax, rfc1902.IpAddress):
-                val = '.'.join(
-                    [ str(random.randrange(1, 256)) for x in range(4) ]
-                )
+                val = '.'.join([str(random.randrange(1, 256)) for x in range(4)])
             elif isinstance(syntax, rfc1902.TimeTicks):
                 val = random.randrange(timeticksRange[0], timeticksRange[1])
             elif isinstance(syntax, rfc1902.Gauge32):
@@ -204,19 +225,30 @@ def getValue(syntax, hint='', automaticValues=automaticValues):
             elif isinstance(syntax, rfc1902.Counter64):
                 val = random.randrange(counter64Range[0], counter64Range[1])
             elif isinstance(syntax, univ.OctetString):
-                val = ' '.join(
-                    [ stringPool[i] for i in range(random.randrange(0, len(stringPool)), random.randrange(0, len(stringPool))) ]
-                )
+                maxWords = 10
+                val = ' '.join([stringPool[random.randrange(0, len(stringPool))] for i in range(random.randrange(1, maxWords))])
             elif isinstance(syntax, univ.ObjectIdentifier):
-                val = '.'.join(['1','3','6','1','3'] + ['%d' % random.randrange(0, 255) for x in range(random.randrange(0, 10))])
+                val = '.'.join(['1', '3', '6', '1', '3'] + [
+                    '%d' % random.randrange(0, 255) for x in range(random.randrange(0, 10))])
             elif isinstance(syntax, rfc1902.Bits):
-                val = [random.randrange(0, 256) for x in range(random.randrange(0,9))]
+                val = [random.randrange(0, 256) for x in range(random.randrange(0, 9))]
             else:
                 val = '?'
 
         try:
-            if val is not None:
-                return syntax.clone(val)
+            # remove value enumeration
+
+            if syntax.tagSet == rfc1902.Integer32.tagSet:
+                return rfc1902.Integer32(syntax.clone(val))
+
+            if syntax.tagSet == rfc1902.Unsigned32.tagSet:
+                return rfc1902.Unsigned32(syntax.clone(val))
+
+            if syntax.tagSet == rfc1902.Bits.tagSet:
+                return rfc1902.OctetString(syntax.clone(val))
+
+            return syntax.clone(val)
+
         except PyAsn1Error:
             if makeGuess == 1:
                 sys.stderr.write(
@@ -226,9 +258,7 @@ def getValue(syntax, hint='', automaticValues=automaticValues):
                 makeGuess -= 1
                 continue
 
-        sys.stderr.write(
-            '%s# Value [\'%s\'] ? ' % (hint,(val is None and '<none>' or val),)
-            )
+        sys.stderr.write('%s# Value [\'%s\'] ? ' % (hint, (val is None and '<none>' or val),))
         sys.stderr.flush()
         line = sys.stdin.readline().strip()
         if line:
@@ -242,6 +272,7 @@ def getValue(syntax, hint='', automaticValues=automaticValues):
             else:
                 val = line
 
+
 # Data file builder
 
 dataFileHandler = snmprec.SnmprecRecord()
@@ -250,21 +281,21 @@ mibBuilder = builder.MibBuilder()
 
 mibBuilder.setMibSources(
     *mibBuilder.getMibSources() + tuple(
-      [ builder.ZipMibSource(m).init() for m in mibDirs ]
+        [builder.ZipMibSource(m).init() for m in mibDirs]
     )
 )
 
 # Load MIB tree foundation classes
-( MibScalar,
-  MibTable,
-  MibTableRow,
-  MibTableColumn ) = mibBuilder.importSymbols(
+(MibScalar,
+ MibTable,
+ MibTableRow,
+ MibTableColumn) = mibBuilder.importSymbols(
     'SNMPv2-SMI',
     'MibScalar',
     'MibTable',
     'MibTableRow',
     'MibTableColumn'
-    )
+)
 
 mibViewController = view.MibViewController(mibBuilder)
 
@@ -282,10 +313,12 @@ output = []
 for modName in modNames:
     if verboseFlag:
         sys.stderr.write('# MIB module: %s, from %s till %s\r\n' % (modName, startOID or 'the beginning', stopOID or 'the end'))
-    modOID = oid = ObjectIdentity(modName).resolveWithMib(mibViewController)
-    hint = ''
+    oid = ObjectIdentity(modName).resolveWithMib(mibViewController)
+    hint = rowHint = ''
     rowOID = None
-    while modOID.isPrefixOf(oid):
+    suffix = ()
+    thisTableSize = 0
+    while True:
         try:
             oid, label, _ = mibViewController.getNextNodeName(oid)
         except error.NoSuchObjectError:
@@ -303,10 +336,8 @@ for modName in modNames:
                         sys.stderr.write('# Finished table %s (%d rows)\r\n' % (rowOID, thisTableSize))
                     rowOID = None
             else:
-                while 1:
-                    sys.stderr.write(
-                        '# Synthesize row #%d for table %s (y/n)? ' % (thisTableSize, rowOID)
-                    )
+                while True:
+                    sys.stderr.write('# Synthesize row #%d for table %s (y/n)? ' % (thisTableSize, rowOID))
                     sys.stderr.flush()
                     line = sys.stdin.readline().strip()
                     if line:
@@ -320,13 +351,13 @@ for modName in modNames:
                             break
 
         if startOID and oid < startOID:
-            continue # skip on premature OID
+            continue  # skip on premature OID
         if stopOID and oid > stopOID:
             break  # stop on out of range condition
 
         mibName, symName, _ = mibViewController.getNodeLocation(oid)
         node, = mibBuilder.importSymbols(mibName, symName)
-    
+
         if isinstance(node, MibTable):
             hint = '# Table %s::%s\r\n' % (mibName, symName)
             if verboseFlag:
@@ -341,6 +372,9 @@ for modName in modNames:
                 rowHint += '# Index %s::%s (type %s)\r\n' % (idxModName, idxSymName, idxNode.syntax.__class__.__name__)
                 rowIndices[idxNode.name] = getValue(idxNode.syntax, verboseFlag and rowHint or '')
                 suffix = suffix + node.getAsName(rowIndices[idxNode.name], impliedFlag)
+            if not rowIndices:
+                if verboseFlag:
+                    sys.stderr.write('# WARNING: %s::%s table has no index!\r\n' % (mibName, symName))
             if rowOID is None:
                 thisTableSize = 0
             rowOID = univ.ObjectIdentifier(oid)
@@ -350,7 +384,8 @@ for modName in modNames:
             if oid in rowIndices:
                 val = rowIndices[oid]
             else:
-                val = getValue(node.syntax, verboseFlag and rowHint + '# Column %s::%s (type %s)\r\n' % (mibName, symName, node.syntax.__class__.__name__) or '')
+                val = getValue(node.syntax,
+                               verboseFlag and rowHint + '# Column %s::%s (type %s)\r\n' % (mibName, symName, node.syntax.__class__.__name__) or '')
         elif isinstance(node, MibScalar):
             hint = ''
             oid = node.name
@@ -359,37 +394,29 @@ for modName in modNames:
         else:
             hint = ''
             continue
-  
+
         output.append((oid + suffix, val))
-    
-    output.sort(
-        key=lambda x: univ.ObjectIdentifier(x[0])
-    )
+
+    output.sort(key=lambda x: univ.ObjectIdentifier(x[0]))
 
     unique = set()
 
     for oid, val in output:
         if oid in unique:
             if verboseFlag:
-                sys.stderr.write(
-                    '# Dropping duplicate OID %s\r\n' % (univ.ObjectIdentifier(oid),)
-                )
+                sys.stderr.write('# Dropping duplicate OID %s\r\n' % (univ.ObjectIdentifier(oid),))
         else:
             try:
                 outputFile.write(
                     dataFileHandler.format(oid, val)
                 )
             except SnmpsimError:
-                sys.stderr.write(
-                    'ERROR: %s\r\n' % (sys.exc_info()[1],)
-                )
+                sys.stderr.write('ERROR: %s\r\n' % (sys.exc_info()[1],))
             else:
                 unique.add(oid)
 
     if verboseFlag:
-        sys.stderr.write(
-            '# End of %s, %s OID(s) dumped\r\n' % (modName, len(unique))
-        )
+        sys.stderr.write('# End of %s, %s OID(s) dumped\r\n' % (modName, len(unique)))
 
 outputFile.flush()
 outputFile.close()
