@@ -1,8 +1,11 @@
 #!/usr/bin/env python
 #
-# SNMP Simulator MIB to data file converter
+# This file is part of snmpsim software.
 #
-# Written by Ilya Etingof <ilya@glas.net>, 2011-2015
+# Copyright (c) 2010-2019, Ilya Etingof <etingof@gmail.com>
+# License: http://snmplabs.com/snmpsim/license.html
+#
+# SNMP Simulator MIB to data file converter
 #
 import getopt
 import sys
@@ -12,6 +15,7 @@ import socket
 import struct
 import bisect
 import traceback
+
 try:
     import pcap
 except ImportError:
@@ -30,12 +34,12 @@ from snmpsim import confdir, error, log
 # Defaults
 verboseFlag = True
 mibSources = []
-defaultMibSources = [ 'http://mibs.snmplabs.com/asn1/@mib@' ]
+defaultMibSources = ['http://mibs.snmplabs.com/asn1/@mib@']
 startOID = univ.ObjectIdentifier('1.3.6')
 stopOID = None
 promiscuousMode = False
 outputDir = '.'
-transportIdOffset= 0
+transportIdOffset = 0
 variationModuleOptions = ""
 variationModuleName = variationModule = None
 listenInterface = captureFile = None
@@ -45,18 +49,18 @@ endpoints = {}
 contexts = {}
 
 stats = {
-  'UDP packets': 0,
-  'IP packets': 0,
-  'bad packets': 0,
-  'empty packets': 0,
-  'unknown L2 protocol': 0,
-  'SNMP errors': 0,
-  'SNMP exceptions': 0,
-  'agents seen': 0,
-  'contexts seen': 0,
-  'snapshots taken': 0,
-  'Response PDUs seen': 0,
-  'OIDs seen': 0
+    'UDP packets': 0,
+    'IP packets': 0,
+    'bad packets': 0,
+    'empty packets': 0,
+    'unknown L2 protocol': 0,
+    'SNMP errors': 0,
+    'SNMP exceptions': 0,
+    'agents seen': 0,
+    'contexts seen': 0,
+    'snapshots taken': 0,
+    'Response PDUs seen': 0,
+    'OIDs seen': 0
 }
 
 helpMessage = """Usage: %s [--help]
@@ -77,30 +81,32 @@ helpMessage = """Usage: %s [--help]
     [--variation-modules-dir=<dir>]
     [--variation-module=<module>]
     [--variation-module-options=<args>]""" % (
-        sys.argv[0],
-        '|'.join([ x for x in pysnmp_debug.flagMap.keys() if x != 'mibview' ]),
-        '|'.join([ x for x in pyasn1_debug.flagMap.keys() ]),
-        '|'.join(log.gMap.keys())
-    )
+    sys.argv[0],
+    '|'.join([x for x in getattr(pysnmp_debug, 'FLAG_MAP', getattr(pysnmp_debug, 'flagMap', ()))
+              if x != 'mibview']),
+    '|'.join([x for x in getattr(pyasn1_debug, 'FLAG_MAP', getattr(pyasn1_debug, 'flagMap', ()))]),
+    '|'.join(log.gMap)
+)
 
 try:
     opts, params = getopt.getopt(sys.argv[1:], 'hv', [
         'help', 'version', 'debug=', 'debug-snmp=', 'debug-asn1=',
-        'quiet', 'logging-method=', 'start-oid=', 'stop-oid=', 
-         'start-object=', 'stop-object=', 'mib-source=',
+        'quiet', 'logging-method=', 'start-oid=', 'stop-oid=',
+        'start-object=', 'stop-object=', 'mib-source=',
         'output-dir=', 'transport-id-offset=',
         'capture-file=', 'listen-interface=', 'promiscuous-mode',
-        'packet-filter=', 
+        'packet-filter=',
         'variation-modules-dir=', 'variation-module=',
         'variation-module-options='
     ])
 except Exception:
-    sys.stderr.write('ERROR: %s\r\n%s\r\n' % (sys.exc_info()[1], helpMessage))
+    sys.stderr.write(
+        'ERROR: %s\r\n%s\r\n' % (sys.exc_info()[1], helpMessage))
     sys.exit(-1)
 
 if params:
     sys.stderr.write('ERROR: extra arguments supplied %s\r\n%s\r\n' % (params, helpMessage))
-    sys.exit(-1)    
+    sys.exit(-1)
 
 for opt in opts:
     if opt[0] == '-h' or opt[0] == '--help':
@@ -110,29 +116,40 @@ Synopsis:
   data files.
   Can read capture files or listen live network interface.
 Documentation:
-  http://snmpsim.sourceforge.net/
+  http://snmplabs.com/snmpsim/
 %s
 """ % helpMessage)
         sys.exit(-1)
     if opt[0] == '-v' or opt[0] == '--version':
-        import snmpsim, pysmi, pysnmp, pyasn1
+        import snmpsim
+        import pysmi
+        import pysnmp
+        import pyasn1
+
         sys.stderr.write("""\
-SNMP Simulator version %s, written by Ilya Etingof <ilya@glas.net>
+SNMP Simulator version %s, written by Ilya Etingof <etingof@gmail.com>
 Using foundation libraries: pysmi %s, pysnmp %s, pyasn1 %s.
 Python interpreter: %s
-Software documentation and support at http://snmpsim.sf.net
+Software documentation and support at http://snmplabs.com/snmpsim
 %s
-""" % (snmpsim.__version__, hasattr(pysmi, '__version__') and pysmi.__version__ or 'unknown', hasattr(pysnmp, '__version__') and pysnmp.__version__ or 'unknown', hasattr(pyasn1, '__version__') and pyasn1.__version__ or 'unknown', sys.version, helpMessage))
+""" % (snmpsim.__version__,
+       hasattr(pysmi, '__version__') and pysmi.__version__ or 'unknown',
+       hasattr(pysnmp, '__version__') and pysnmp.__version__ or 'unknown',
+       hasattr(pyasn1, '__version__') and pyasn1.__version__ or 'unknown',
+       sys.version, helpMessage))
         sys.exit(-1)
     elif opt[0] in ('--debug', '--debug-snmp'):
-        pysnmp_debug.setLogger(pysnmp_debug.Debug(*opt[1].split(','), **dict(loggerName='pcap2dev.pysnmp')))
+        pysnmp_debug.setLogger(pysnmp_debug.Debug(*opt[1].split(','), **dict(
+            loggerName='pcap2dev.pysnmp')))
     elif opt[0] == '--debug-asn1':
-        pyasn1_debug.setLogger(pyasn1_debug.Debug(*opt[1].split(','), **dict(loggerName='pcap2dev.pyasn1')))
+        pyasn1_debug.setLogger(pyasn1_debug.Debug(*opt[1].split(','), **dict(
+            loggerName='pcap2dev.pyasn1')))
     elif opt[0] == '--logging-method':
         try:
             log.setLogger('pcap2dev', *opt[1].split(':'), **dict(force=True))
         except error.SnmpsimError:
-            sys.stderr.write('%s\r\n%s\r\n' % (sys.exc_info()[1], helpMessage))
+            sys.stderr.write(
+                '%s\r\n%s\r\n' % (sys.exc_info()[1], helpMessage))
             sys.exit(-1)
     if opt[0] == '--quiet':
         verboseFlag = False
@@ -145,16 +162,18 @@ Software documentation and support at http://snmpsim.sf.net
     if opt[0] == '--mib-source':
         mibSources.append(opt[1])
     if opt[0] == '--start-object':
-        startOID = rfc1902.ObjectIdentity(*opt[1].split('::'))
+        startOID = rfc1902.ObjectIdentity(*opt[1].split('::', 1))
     if opt[0] == '--stop-object':
-        stopOID = rfc1902.ObjectIdentity(*opt[1].split('::'), **dict(last=True))
+        stopOID = rfc1902.ObjectIdentity(*opt[1].split('::', 1),
+                                         **dict(last=True))
     elif opt[0] == '--output-dir':
         outputDir = opt[1]
     elif opt[0] == '--transport-id-offset':
         try:
             transportIdOffset = max(0, int(opt[1]))
         except:
-            sys.stderr.write('ERROR: %s\r\n%s\r\n' % (sys.exc_info()[1], helpMessage))
+            sys.stderr.write(
+                'ERROR: %s\r\n%s\r\n' % (sys.exc_info()[1], helpMessage))
             sys.exit(-1)
     elif opt[0] == '--listen-interface':
         listenInterface = opt[1]
@@ -170,13 +189,14 @@ Software documentation and support at http://snmpsim.sf.net
         variationModuleName = opt[1]
     elif opt[0] == '--variation-module-options':
         variationModuleOptions = opt[1]
- 
+
 if params:
-    sys.stderr.write('ERROR: extra arguments supplied %s\r\n%s\r\n' % (params, helpMessage))
-    sys.exit(-1)    
+    sys.stderr.write('ERROR: extra arguments supplied %s\r\n%s\r\n' % (
+    params, helpMessage))
+    sys.exit(-1)
 
 if not pcap:
-    sys.stderr.write('ERROR: pylibpcap package is missing!\r\nGet it from http://sourceforge.net/projects/pylibpcap/\r\n%s\r\n' % helpMessage)
+    sys.stderr.write('ERROR: pylibpcap package is missing!\r\nGet it by running `pip install https://downloads.sourceforge.net/project/pylibpcap/pylibpcap/0.6.4/pylibpcap-0.6.4.tar.gz`\r\n%s\r\n' % helpMessage)
     sys.exit(-1)
 
 log.setLogger('pcap2dev', 'stdout')
@@ -209,16 +229,18 @@ if variationModuleName:
             log.msg('Variation module "%s" not found' % mod)
             continue
 
-        ctx = { 'path': mod, 'moduleContext': {} }
+        ctx = {'path': mod, 'moduleContext': {}}
 
         try:
             if sys.version_info[0] > 2:
                 exec(compile(open(mod).read(), mod, 'exec'), ctx)
             else:
                 execfile(mod, ctx)
+
         except Exception:
-            log.msg('Variation module "%s" execution failure: %s' %  (mod, sys.exc_info()[1]))
+            log.msg('Variation module "%s" execution failure: %s' % (mod, sys.exc_info()[1]))
             sys.exit(-1)
+
         else:
             variationModule = ctx
             log.msg('Variation module "%s" loaded' % variationModuleName)
@@ -226,7 +248,7 @@ if variationModuleName:
     else:
         log.msg('ERROR: variation module "%s" not found' % variationModuleName)
         sys.exit(-1)
- 
+
 # Variation module initialization
 
 if variationModule:
@@ -245,6 +267,7 @@ if variationModule:
     else:
         log.msg('Variation module "%s" initialization OK' % variationModuleName)
 
+
 # Data file builder
 
 class SnmprecRecord(snmprec.SnmprecRecord):
@@ -263,7 +286,8 @@ class SnmprecRecord(snmprec.SnmprecRecord):
             else:
                 textTag, textValue = plainTag, plainValue
 
-            textOid, textTag, textValue = context['variationModule']['record'](
+            textOid, textTag, textValue = context['variationModule'][
+                'record'](
                 textOid, textTag, textValue, **context
             )
 
@@ -272,25 +296,26 @@ class SnmprecRecord(snmprec.SnmprecRecord):
 
         return textOid, textTag, textValue
 
+
 pcapObj = pcap.pcapObject()
 
 if listenInterface:
     if verboseFlag:
-        log.msg('Listening on interface %s in %spromiscuous mode' % (listenInterface, promiscuousMode == False and 'non-' or ''))
+        log.msg('Listening on interface %s in %spromiscuous mode' % (listenInterface, promiscuousMode is False and 'non-' or ''))
     try:
         pcapObj.open_live(listenInterface, 65536, promiscuousMode, 1000)
-    except:
-        log.msg('Error openning interface %s for snooping: %s' % (listenInterface, sys.exc_info()[1]))
+    except Exception:
+        log.msg('Error opening interface %s for snooping: %s' % (listenInterface, sys.exc_info()[1]))
         sys.exit(-1)
 elif captureFile:
     if verboseFlag:
-        log.msg('Openning capture file %s' % captureFile)
+        log.msg('Opening capture file %s' % captureFile)
     try:
         pcapObj.open_offline(captureFile)
-    except:
-        log.msg('Error openning capture file %s for reading: %s' % (captureFile, sys.exc_info()[1]))
+    except Exception:
+        log.msg('Error opening capture file %s for reading: %s' % (captureFile, sys.exc_info()[1]))
         sys.exit(-1)
-else: 
+else:
     sys.stderr.write('ERROR: no capture file or live interface specified\r\n%s\r\n' % helpMessage)
     sys.exit(-1)
 
@@ -302,8 +327,9 @@ if packetFilter:
 if verboseFlag:
     log.msg('Processing records from %s till %s' % (startOID or 'the beginning', stopOID or 'the end'))
 
+
 def parsePacket(s):
-    d={}
+    d = {}
 
     # http://www.tcpdump.org/linktypes.html
     llHeaders = {
@@ -317,62 +343,65 @@ def parsePacket(s):
         s = s[llHeaders[pcapObj.datalink()]:]
     else:
         stats['unknown L2 protocol'] += 1
- 
-    d['version']=(ord(s[0]) & 0xf0) >> 4
-    d['header_len']=ord(s[0]) & 0x0f
-    d['tos']=ord(s[1])
-    d['total_len']=socket.ntohs(struct.unpack('H',s[2:4])[0])
-    d['id']=socket.ntohs(struct.unpack('H',s[4:6])[0])
-    d['flags']=(ord(s[6]) & 0xe0) >> 5
-    d['fragment_offset']=socket.ntohs(struct.unpack('H',s[6:8])[0] & 0x1f)
-    d['ttl']=ord(s[8])
-    d['protocol']=ord(s[9])
-    d['checksum']=socket.ntohs(struct.unpack('H',s[10:12])[0])
-    d['source_address']=pcap.ntoa(struct.unpack('i',s[12:16])[0])
-    d['destination_address']=pcap.ntoa(struct.unpack('i',s[16:20])[0])
-    if d['header_len']>5:
-        d['options']=s[20:4*(d['header_len']-5)]
+
+    d['version'] = (ord(s[0]) & 0xf0) >> 4
+    d['header_len'] = ord(s[0]) & 0x0f
+    d['tos'] = ord(s[1])
+    d['total_len'] = socket.ntohs(struct.unpack('H', s[2:4])[0])
+    d['id'] = socket.ntohs(struct.unpack('H', s[4:6])[0])
+    d['flags'] = (ord(s[6]) & 0xe0) >> 5
+    d['fragment_offset'] = socket.ntohs(struct.unpack('H', s[6:8])[0] & 0x1f)
+    d['ttl'] = ord(s[8])
+    d['protocol'] = ord(s[9])
+    d['checksum'] = socket.ntohs(struct.unpack('H', s[10:12])[0])
+    d['source_address'] = pcap.ntoa(struct.unpack('i', s[12:16])[0])
+    d['destination_address'] = pcap.ntoa(struct.unpack('i', s[16:20])[0])
+    if d['header_len'] > 5:
+        d['options'] = s[20:4 * (d['header_len'] - 5)]
     else:
-        d['options']=None
-    s = s[4*d['header_len']:]
+        d['options'] = None
+    s = s[4 * d['header_len']:]
     if d['protocol'] == 17:
-        d['source_port'] = socket.ntohs(struct.unpack('H',s[0:2])[0])
-        d['destination_port'] = socket.ntohs(struct.unpack('H',s[2:4])[0])
+        d['source_port'] = socket.ntohs(struct.unpack('H', s[0:2])[0])
+        d['destination_port'] = socket.ntohs(struct.unpack('H', s[2:4])[0])
         s = s[8:]
-        stats['UDP packets'] +=1
+        stats['UDP packets'] += 1
     d['data'] = s
-    stats['IP packets'] +=1
+    stats['IP packets'] += 1
     return d
 
+
 def handleSnmpMessage(d, t, private={}):
     msgVer = api.decodeMessageVersion(d['data'])
     if msgVer in api.protoModules:
         pMod = api.protoModules[msgVer]
     else:
-        stats['bad packets'] +=1
+        stats['bad packets'] += 1
         return
     try:
         rspMsg, wholeMsg = decoder.decode(
             d['data'], asn1Spec=pMod.Message(),
         )
     except PyAsn1Error:
-        stats['bad packets'] +=1
+        stats['bad packets'] += 1
         return
     if rspMsg['data'].getName() == 'response':
         rspPDU = pMod.apiMessage.getPDU(rspMsg)
         errorStatus = pMod.apiPDU.getErrorStatus(rspPDU)
         if errorStatus:
-            stats['SNMP errors'] +=1
+            stats['SNMP errors'] += 1
         else:
             endpoint = d['source_address'], d['source_port']
             if endpoint not in endpoints:
                 endpoints[endpoint] = udp.domainName + (transportIdOffset + len(endpoints),)
-                stats['agents seen'] +=1
-            context = '%s/%s' % (pMod.ObjectIdentifier(endpoints[endpoint]), pMod.apiMessage.getCommunity(rspMsg))
+                stats['agents seen'] += 1
+            context = '%s/%s' % (pMod.ObjectIdentifier(endpoints[endpoint]),
+                                 pMod.apiMessage.getCommunity(rspMsg))
             if context not in contexts:
                 contexts[context] = {}
-                stats['contexts seen'] +=1
-            context = '%s/%s' % (pMod.ObjectIdentifier(endpoints[endpoint]), pMod.apiMessage.getCommunity(rspMsg))
+                stats['contexts seen'] += 1
+            context = '%s/%s' % (pMod.ObjectIdentifier(endpoints[endpoint]),
+                                 pMod.apiMessage.getCommunity(rspMsg))
 
             stats['Response PDUs seen'] += 1
 
@@ -386,13 +415,14 @@ def handleSnmpMessage(d, t, private={}):
                     continue
                 if oid in contexts[context]:
                     if value != contexts[context][oid]:
-                        stats['snapshots taken'] +=1
+                        stats['snapshots taken'] += 1
                 else:
                     contexts[context][oid] = [], []
                 contexts[context][oid][0].append(t - private['basetime'])
                 contexts[context][oid][1].append(value)
                 stats['OIDs seen'] += 1
 
+
 def handlePacket(pktlen, data, timestamp):
     if not data:
         stats['empty packets'] += 1
@@ -400,12 +430,14 @@ def handlePacket(pktlen, data, timestamp):
     else:
         handleSnmpMessage(parsePacket(data), timestamp)
 
+
 exc_info = None
 
 try:
     if listenInterface:
-        log.msg('Listening on interface "%s", kill me when you are done.' % listenInterface)
-        while 1:
+        log.msg(
+            'Listening on interface "%s", kill me when you are done.' % listenInterface)
+        while True:
             pcapObj.dispatch(1, handlePacket)
     elif captureFile:
         log.msg('Processing capture file "%s"....' % captureFile)
@@ -423,7 +455,8 @@ except Exception:
 dataFileHandler = SnmprecRecord()
 
 for context in contexts:
-    filename = os.path.join(outputDir, context + os.path.extsep + SnmprecRecord.ext)
+    filename = os.path.join(outputDir,
+                            context + os.path.extsep + SnmprecRecord.ext)
     if verboseFlag:
         log.msg('Creating simulation context %s at %s' % (context, filename))
     try:
@@ -446,7 +479,8 @@ for context in contexts:
         for oid in oids:
             timeline, values = contexts[context][oid]
             value = values[
-                min(len(values)-1, bisect.bisect_left(timeline, timeOffset))
+                min(len(values) - 1,
+                    bisect.bisect_left(timeline, timeOffset))
             ]
             if value.tagSet in (rfc1905.NoSuchObject.tagSet,
                                 rfc1905.NoSuchInstance.tagSet,
@@ -454,6 +488,17 @@ for context in contexts:
                 stats['SNMP exceptions'] += 1
                 continue
 
+            # remove value enumeration
+
+            if value.tagSet == rfc1902.Integer32.tagSet:
+                value = rfc1902.Integer32(value)
+
+            if value.tagSet == rfc1902.Unsigned32.tagSet:
+                value = rfc1902.Unsigned32(value)
+
+            if value.tagSet == rfc1902.Bits.tagSet:
+                value = rfc1902.OctetString(value)
+
             # Build .snmprec record
 
             ctx = {
@@ -465,7 +510,7 @@ for context in contexts:
                 'reqTime': reqTime,
                 'startOID': startOID,
                 'stopOID': stopOID,
-                'stopFlag': oids.index(oid) == len(oids)-1,
+                'stopFlag': oids.index(oid) == len(oids) - 1,
                 'variationModule': variationModule
             }
 
@@ -478,9 +523,10 @@ for context in contexts:
                 moreDataNotification = sys.exc_info()[1]
                 if 'period' in moreDataNotification:
                     timeOffset += moreDataNotification['period']
-                    log.msg('%s OIDs dumped, advancing time window to %.2f sec(s)...' % (total, timeOffset))
+                    log.msg(
+                        '%s OIDs dumped, advancing time window to %.2f sec(s)...' % (total, timeOffset))
                 break
- 
+
             except error.NoDataNotification:
                 pass
             except error.SnmpsimError:
@@ -513,7 +559,7 @@ log.msg("""PCap statistics:
     packets dropped: %s
     packets dropped: by interface %s""" % pcapObj.stats())
 log.msg("""SNMP statistics:
-    %s""" % '    '.join([ '%s: %s\r\n' % kv for kv in stats.items() ]))
+    %s""" % '    '.join(['%s: %s\r\n' % kv for kv in stats.items()]))
 
 if exc_info:
     for line in traceback.format_exception(*exc_info):
