@@ -1,16 +1,23 @@
+#
+# This file is part of snmpsim software.
+#
+# Copyright (c) 2010-2019, Ilya Etingof <etingof@gmail.com>
+# License: http://snmplabs.com/snmpsim/license.html
+#
 from pysnmp.proto import rfc1902
 from pyasn1.type import univ
 from pyasn1.compat.octets import octs2str
-from snmpsim.grammar import abstract, dump
+from snmpsim.grammar import abstract
 from snmpsim import error
 
+
 class SapGrammar(abstract.AbstractGrammar):
     tagMap = {
         'Counter': rfc1902.Counter32,
         'Gauge': rfc1902.Gauge32,
         'Integer': rfc1902.Integer32,
         'IpAddress': rfc1902.IpAddress,
-#        '<not implemented?>': univ.Null,
+        #        '<not implemented?>': univ.Null,
         'ObjectID': univ.ObjectIdentifier,
         'OctetString': rfc1902.OctetString,
         'TimeTicks': rfc1902.TimeTicks,
@@ -19,7 +26,7 @@ class SapGrammar(abstract.AbstractGrammar):
 
     def __stringFilter(value):
         if value[:2] == '0x':
-            value = [ int(value[x:x+2], 16) for x in range(2, len(value[2:])+2, 2) ]
+            value = [int(value[x:x + 2], 16) for x in range(2, len(value[2:]) + 2, 2)]
         return value
 
     filterMap = {
